///File : MainFrame.cpp
//------------------------------------------------------------------------------
/*
    This file is part of resistancevalue.

    Resistancevalue is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Resistancevalue is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with resistancevalue.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "MainFrame.hpp"
#include "DialogAbout.hpp"
#include "findFile.hpp"
//------------------------------------------------------------------------------
/*BEGIN_EVENT_TABLE(MainFrame, wxFrame)
    EVT_MENU(wxID_EXIT,  MainFrame::OnQuit)
    EVT_MENU(wxID_ABOUT, MainFrame::OnAbout)
END_EVENT_TABLE()*/
//------------------------------------------------------------------------------
MainFrame::MainFrame(const wxString& title, const wxPoint& pos, const wxSize& size, long style) : wxFrame(NULL, -1, title, pos, size, style)
{
    // Presentation général
    #if defined(__WXMSW__)
        SetIcon(wxIcon(_T("myicon")));
    #elif defined(__UNIX__)
        wxString ImgFileName = findFile(_T("data/resistancevalue-icone.png"));
        if(wxFileExists(ImgFileName))
        {
            SetIcon(wxIcon(ImgFileName, wxBITMAP_TYPE_PNG));
        }
    #endif //#ifdef WIN32

    // Menus
    m_FileMenu = new wxMenu;
    m_FileMenu->Append(wxID_EXIT, _("&Quit"));

    m_HelpMenu = new wxMenu;
    m_HelpMenu->Append(wxID_ABOUT, _("&About"));

    m_MenuBar = new wxMenuBar();
    m_MenuBar->Append(m_FileMenu,_("&File"));
    m_MenuBar->Append(m_HelpMenu,_("&Help"));

    SetMenuBar(m_MenuBar);

    // Corp
	wxBoxSizer* MainSizer = new wxBoxSizer( wxVERTICAL );

    m_MainNotebook = new wxNotebook(this, wxID_ANY);
    MainSizer->Add(m_MainNotebook, 1, wxEXPAND);

    m_MyPanelResistanceColorToValue = new PanelResistanceColorToValue(m_MainNotebook, wxID_ANY);
    m_MainNotebook->AddPage(m_MyPanelResistanceColorToValue, _("Color to Value"), true);

    m_MyPanelResistanceValueToColor = new PanelResistanceValueToColor(m_MainNotebook, wxID_ANY);
    m_MainNotebook->AddPage(m_MyPanelResistanceValueToColor, _("Value to Color"));

	SetSizer( MainSizer );

    Connect( wxID_EXIT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnQuit));
    Connect( wxID_ABOUT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnAbout));
}
//------------------------------------------------------------------------------
void MainFrame::OnQuit(wxCommandEvent& WXUNUSED(event))
{
    exit (EXIT_SUCCESS);
}
//------------------------------------------------------------------------------
void MainFrame::OnAbout(wxCommandEvent& WXUNUSED(event))
{
    DialogAbout MyDialogAbout(this, wxID_ANY);
    MyDialogAbout.ShowModal();

}
//------------------------------------------------------------------------------
